@@ -482,7 +482,11 @@ class SwitchbotBaseDevice:
 
     def _set_advertisement_data(self, advertisement: SwitchBotAdvertisement) -> None:
         """Set advertisement data."""
-        if advertisement.data.get("data") or not self._sb_adv_data.data.get("data"):
+        if (
+            advertisement.data.get("data")
+            or not self._sb_adv_data
+            or not self._sb_adv_data.data.get("data")
+        ):
             self._sb_adv_data = advertisement
         self._override_adv_data = None
 
